#!/bin/bash
#
# Author Krigler Pavol
# Version 0.3.2
#
# Bash script Cisco Template Manager (CTM) for printing interface templates.
#
# Copyright 2010 Pavol Krigler <pavol.krigler@gelogic.net>
#
# This file is part of Cisco Template Manager.
#
#    CTM is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    CTM is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with CTM.  If not, see <http://www.gnu.org/licenses/>.

# CTM configuration file
CONFIGFILE="/etc/ctm/ctm.conf"

# Constants
AVAILABLE_TEMPLATES=1

# Read configuration file
if [ ! -s "$CONFIGFILE" ]; then 
	echo "ERROR: CTM configuration file '$CONFIGFILE' not found or is empty"
	exit 1
fi

. $CONFIGFILE

cd $TEMPLATE_DIR

if [ $# -lt 3 ]; then
	echo "Usage: $0 DEVICE ROLE SERVICE_ID [detail]"
	echo "Usage: $0 ? ? ? [detail]"
	echo ""
	echo "Mandatory arguments:"
	echo "  DEVICE         select device template which would you like to show"
	echo "  ROLE           select role of the device"
	echo "  SERVICE_ID     name of the service identificator"
	echo ""
	echo "Optional argument:"
	echo "  detail         show complete device configuration template"

	if [ $AVAILABLE_TEMPLATES -eq 1 ]; then
		echo ""
	        echo "List of available templates and roles:"
	        for ENTRY in $(ls -1); do
	                printf "%-18s" $ENTRY; ls -1 $ENTRY | tr '\n' '/' | sed -e 's/\/$//'
	                echo
	        done
	fi
	exit
fi

DEV_NAME=$1
ROLE=$2

RESULT=$(find . -follow -type f -iname "*${3}*.model" -o -type l -iname "*${3}*.model" | egrep ".*$DEV_NAME.*/$ROLE/")

for LINE in $RESULT; do
	DEVICE=$(echo $LINE | cut -d "/" -f 2)
	ROLE=$(echo $LINE | cut -d "/" -f 3)
	SERVICE=$(echo $LINE | cut -d "/" -f 5 | sed -e 's/.model//')

	test -z "$SERVICE" && continue
	
	echo -e "DEVICE=$DEVICE\tROLE=$ROLE\tSERVICE_ID=$SERVICE"
	if [ -n "$4" ] && [ $4 = "detail" ]; then
		echo '-------%<-------'
		echo "grep EXAMPLE $TEMPLATE_DIR/$DEVICE/$ROLE/services/$SERVICE.def"
		echo -n "description "; grep EXAMPLE $TEMPLATE_DIR/$DEVICE/$ROLE/services/$SERVICE.def | sed -e 's/.*=//' | tr -d '"'
		grep -v "^description" $TEMPLATE_DIR/$DEVICE/$ROLE/services/$SERVICE.model
		echo '------->%-------'
		echo
	fi
done

